@@ -641,7 +641,8 @@ run (void *cls,
   }
 
   if (NULL ==
-      (db = SYNC_DB_plugin_load (config)))
+      (db = SYNC_DB_plugin_load (config,
+                                 false)))
   {
     global_ret = EXIT_NOTCONFIGURED;
     GNUNET_SCHEDULER_shutdown ();
@@ -728,12 +729,8 @@ main (int argc,
   };
   enum GNUNET_GenericReturnValue ret;
 
-  /* FIRST get the libtalerutil initialization out
-     of the way. Then throw that one away, and force
-     the SYNC defaults to be used! */
-  (void) TALER_project_data_default ();
-  GNUNET_OS_init (SYNC_project_data_default ());
-  ret = GNUNET_PROGRAM_run (argc, argv,
+  ret = GNUNET_PROGRAM_run (SYNC_project_data (),
+                            argc, argv,
                             "sync-httpd",
                             "sync HTTP interface",
                             options,
