@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2014-2023 Taler Systems SA
+  Copyright (C) 2014-2024 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as
@@ -65,17 +65,17 @@
 /**
  * Payto URI of the customer (payer).
  */
-static char *payer_payto;
+static struct TALER_FullPayto payer_payto;
 
 /**
  * Payto URI of the exchange (escrow account).
  */
-static char *exchange_payto;
+static struct TALER_FullPayto exchange_payto;
 
 /**
  * Payto URI of the merchant (receiver).
  */
-static char *merchant_payto;
+static struct TALER_FullPayto merchant_payto;
 
 /**
  * Configuration of the bank.
@@ -100,7 +100,7 @@ static const char *sync_url = "http://localhost:8084/";
  * @param label label to use for the command.
  */
 static struct TALER_TESTING_Command
-cmd_exec_wirewatch (char *label)
+cmd_exec_wirewatch (const char *label)
 {
   return TALER_TESTING_cmd_exec_wirewatch (label,
                                            CONFIG_FILE);
@@ -141,6 +141,7 @@ run (void *cls,
                                     CONFIG_FILE,
                                     "-efms",
                                     "-u", "exchange-account-exchange",
+                                    "-r", "merchant-exchange-default",
                                     NULL),
     TALER_TESTING_cmd_get_exchange ("get-exchange",
                                     cred.cfg,
@@ -265,13 +266,14 @@ main (int argc,
       char *const *argv)
 {
   (void) argc;
-  payer_payto =
-    "payto://x-taler-bank/localhost/" USER_ACCOUNT_NAME "?receiver-name=user";
-  exchange_payto =
-    "payto://x-taler-bank/localhost/" EXCHANGE_ACCOUNT_NAME
+  payer_payto.full_payto =
+    (char *) "payto://x-taler-bank/localhost/" USER_ACCOUNT_NAME
+    "?receiver-name=user";
+  exchange_payto.full_payto =
+    (char *) "payto://x-taler-bank/localhost/" EXCHANGE_ACCOUNT_NAME
     "?receiver-name=exchange";
-  merchant_payto =
-    "payto://x-taler-bank/localhost/" MERCHANT_ACCOUNT_NAME
+  merchant_payto.full_payto =
+    (char *) "payto://x-taler-bank/localhost/" MERCHANT_ACCOUNT_NAME
     "?receiver-name=merchant";
   return TALER_TESTING_main (argv,
                              "DEBUG",
